macro_rules! log {
(label: $lbl:expr, $($arg:tt)+) => { ... };
($($arg:tt)+) => { ... };
}Expand description
Prints a message with no or the provided label
log!("Hello, world!");macro_rules! log {
(label: $lbl:expr, $($arg:tt)+) => { ... };
($($arg:tt)+) => { ... };
}Prints a message with no or the provided label
log!("Hello, world!");